@@ -1,26 +1,26 @@
-# redMine - project management software
-# Copyright (C) 2006  Jean-Philippe Lang
+# Redmine - project management software
+# Copyright (C) 2006-2011  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 class RolesController < ApplicationController
   layout 'admin'
-  
+
   before_filter :require_admin
 
-  verify :method => :post, :only => [ :destroy, :move ],
+  verify :method => :post, :only => [ :destroy ],
          :redirect_to => { :action => :index }
 
   def index
@@ -38,9 +38,10 @@ class RolesController < ApplicationController
       end
       flash[:notice] = l(:notice_successful_create)
       redirect_to :action => 'index'
+    else
+      @permissions = @role.setable_permissions
+      @roles = Role.find :all, :order => 'builtin, position'
     end
-    @permissions = @role.setable_permissions
-    @roles = Role.find :all, :order => 'builtin, position'
   end
 
   def edit
@@ -48,8 +49,9 @@ class RolesController < ApplicationController
     if request.post? and @role.update_attributes(params[:role])
       flash[:notice] = l(:notice_successful_update)
       redirect_to :action => 'index'
+    else
+      @permissions = @role.setable_permissions
     end
-    @permissions = @role.setable_permissions
   end
 
   def destroy
@@ -60,8 +62,8 @@ class RolesController < ApplicationController
     flash[:error] =  l(:error_can_not_remove_role)
     redirect_to :action => 'index'
   end
-  
-  def report    
+
+  def report
     @roles = Role.find(:all, :order => 'builtin, position')
     @permissions = Redmine::AccessControl.permissions.select { |p| !p.public? }
     if request.post?
