@@ -20,12 +20,13 @@ class Change < ActiveRecord::Base
 
   validates_presence_of :changeset_id, :action, :path
   before_save :init_path
+  before_validation :replace_invalid_utf8_of_path
 
   def relative_path
     changeset.repository.relative_path(path)
   end
 
-  def before_validation
+  def replace_invalid_utf8_of_path
     self.path      = Redmine::CodesetUtil.replace_invalid_utf8(self.path)
     self.from_path = Redmine::CodesetUtil.replace_invalid_utf8(self.from_path)
   end
