@@ -5,12 +5,12 @@
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -19,29 +19,31 @@ class CustomField < ActiveRecord::Base
   has_many :custom_values, :dependent => :delete_all
   acts_as_list :scope => 'type = \'#{self.class}\''
   serialize :possible_values
-  
+
   validates_presence_of :name, :field_format
   validates_uniqueness_of :name, :scope => :type
   validates_length_of :name, :maximum => 30
   validates_inclusion_of :field_format, :in => Redmine::CustomFieldFormat.available_formats
 
+  validate :validate_values
+
   def initialize(attributes = nil)
     super
     self.possible_values ||= []
   end
-  
+
   def before_validation
     # make sure these fields are not searchable
     self.searchable = false if %w(int float date bool).include?(field_format)
     true
   end
-  
-  def validate
+
+  def validate_values
     if self.field_format == "list"
       errors.add(:possible_values, :blank) if self.possible_values.nil? || self.possible_values.empty?
       errors.add(:possible_values, :invalid) unless self.possible_values.is_a? Array
     end
-    
+
     if regexp.present?
       begin
         Regexp.new(regexp)
@@ -49,13 +51,13 @@ class CustomField < ActiveRecord::Base
         errors.add(:regexp, :invalid)
       end
     end
-    
+
     # validate default value
     v = CustomValue.new(:custom_field => self.clone, :value => default_value, :customized => nil)
     v.custom_field.is_required = false
     errors.add(:default_value, :invalid) unless v.valid?
   end
-  
+
   def possible_values_options(obj=nil)
     case field_format
     when 'user', 'version'
@@ -75,7 +77,7 @@ class CustomField < ActiveRecord::Base
       read_attribute :possible_values
     end
   end
-  
+
   def possible_values(obj=nil)
     case field_format
     when 'user', 'version'
@@ -84,7 +86,7 @@ class CustomField < ActiveRecord::Base
       read_attribute :possible_values
     end
   end
-  
+
   # Makes possible_values accept a multiline string
   def possible_values=(arg)
     if arg.is_a?(Array)
@@ -93,7 +95,7 @@ class CustomField < ActiveRecord::Base
       self.possible_values = arg.to_s.split(/[\n\r]+/)
     end
   end
-  
+
   def cast_value(value)
     casted = nil
     unless value.blank?
@@ -114,7 +116,7 @@ class CustomField < ActiveRecord::Base
     end
     casted
   end
-  
+
   # Returns a ORDER BY clause that can used to sort customized
   # objects by their value of the custom field.
   # Returns false, if the custom field can not be used for sorting.
@@ -122,7 +124,7 @@ class CustomField < ActiveRecord::Base
     case field_format
       when 'string', 'text', 'list', 'date', 'bool'
         # COALESCE is here to make sure that blank and NULL values are sorted equally
-        "COALESCE((SELECT cv_sort.value FROM #{CustomValue.table_name} cv_sort" + 
+        "COALESCE((SELECT cv_sort.value FROM #{CustomValue.table_name} cv_sort" +
           " WHERE cv_sort.customized_type='#{self.class.customized_class.name}'" +
           " AND cv_sort.customized_id=#{self.class.customized_class.table_name}.id" +
           " AND cv_sort.custom_field_id=#{id} LIMIT 1), '')"
@@ -130,7 +132,7 @@ class CustomField < ActiveRecord::Base
         # Make the database cast values into numeric
         # Postgresql will raise an error if a value can not be casted!
         # CustomValue validations should ensure that it doesn't occur
-        "(SELECT CAST(cv_sort.value AS decimal(60,3)) FROM #{CustomValue.table_name} cv_sort" + 
+        "(SELECT CAST(cv_sort.value AS decimal(60,3)) FROM #{CustomValue.table_name} cv_sort" +
           " WHERE cv_sort.customized_type='#{self.class.customized_class.name}'" +
           " AND cv_sort.customized_id=#{self.class.customized_class.table_name}.id" +
           " AND cv_sort.custom_field_id=#{id} AND cv_sort.value <> '' AND cv_sort.value IS NOT NULL LIMIT 1)"
@@ -142,17 +144,17 @@ class CustomField < ActiveRecord::Base
   def <=>(field)
     position <=> field.position
   end
-  
+
   def self.customized_class
     self.name =~ /^(.+)CustomField$/
     begin; $1.constantize; rescue nil; end
   end
-  
+
   # to move in project_custom_field
   def self.for_all
     find(:all, :conditions => ["is_for_all=?", true], :order => 'position')
   end
-  
+
   def type_name
     nil
   end
