@@ -45,6 +45,11 @@ class WikiContent < ActiveRecord::Base
     notified.collect(&:mail)
   end
 
+  # Return true if the content is the current page content
+  def current_version?
+    true
+  end
+
   class Version
     belongs_to :page, :class_name => '::WikiPage', :foreign_key => 'page_id'
     belongs_to :author, :class_name => '::User', :foreign_key => 'author_id'
@@ -88,7 +93,9 @@ class WikiContent < ActiveRecord::Base
     def text
       @text ||= case compression
       when 'gzip'
-         Zlib::Inflate.inflate(data)
+        str = Zlib::Inflate.inflate(data)
+        str.force_encoding("UTF-8") if str.respond_to?(:force_encoding)
+        str
       else
         # uncompressed data
         data
@@ -99,6 +106,11 @@ class WikiContent < ActiveRecord::Base
       page.project
     end
 
+    # Return true if the content is the current page content
+    def current_version?
+      page.content.version == self.version
+    end
+
     # Returns the previous version or nil
     def previous
       @previous ||= WikiContent::Version.find(:first,
