@@ -340,9 +340,9 @@ class RedCloth3 < String
     #
     A_HLGN = /(?:(?:<>|<|>|\=|[()]+)+)/
     A_VLGN = /[\-^~]/
-    C_CLAS = '(?:\([^)]+\))'
-    C_LNGE = '(?:\[[^\[\]]+\])'
-    C_STYL = '(?:\{[^}]+\})'
+    C_CLAS = '(?:\([^")]+\))'
+    C_LNGE = '(?:\[[^"\[\]]+\])'
+    C_STYL = '(?:\{[^"}]+\})'
     S_CSPN = '(?:\\\\\d+)'
     S_RSPN = '(?:/\d+)'
     A = "(?:#{A_HLGN}?#{A_VLGN}?|#{A_VLGN}?#{A_HLGN}?)"
