@@ -1,16 +1,16 @@
-# redMine - project management software
-# Copyright (C) 2006-2007  Jean-Philippe Lang
+# Redmine - project management software
+# Copyright (C) 2006-2011  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -23,7 +23,7 @@ module Redmine
           method_name = "macro_#{name}"
           send(method_name, obj, args) if respond_to?(method_name)
         end
-        
+
         def extract_macro_options(args, *keys)
           options = {}
           while args.last.to_s.strip =~ %r{^(.+)\=(.+)$} && keys.include?($1.downcase.to_sym)
@@ -33,17 +33,17 @@ module Redmine
           return [args, options]
         end
       end
-      
+
       @@available_macros = {}
-      
+
       class << self
         # Called with a block to define additional macros.
         # Macro blocks accept 2 arguments:
         # * obj: the object that is rendered
         # * args: macro arguments
-        # 
+        #
         # Plugins can use this method to define new macros:
-        # 
+        #
         #   Redmine::WikiFormatting::Macros.register do
         #     desc "This is my macro"
         #     macro :my_macro do |obj, args|
@@ -53,7 +53,7 @@ module Redmine
         def register(&block)
           class_eval(&block) if block_given?
         end
-              
+
       private
         # Defines a new macro with the given name and block.
         def macro(name, &block)
@@ -63,21 +63,21 @@ module Redmine
           raise "Can not create a macro without a block!" unless block_given?
           Definitions.send :define_method, "macro_#{name}".downcase, &block
         end
-    
+
         # Sets description for the next macro to be defined
         def desc(txt)
           @@desc = txt
         end
       end
-          
+
       # Builtin macros
       desc "Sample macro."
       macro :hello_world do |obj, args|
         "Hello world! Object: #{obj.class.name}, " + (args.empty? ? "Called with no argument." : "Arguments: #{args.join(', ')}")
       end
-    
+
       desc "Displays a list of all available macros, including description if available."
-      macro :macro_list do
+      macro :macro_list do |obj, args|
         out = ''
         @@available_macros.keys.collect(&:to_s).sort.each do |macro|
           out << content_tag('dt', content_tag('code', macro))
@@ -85,7 +85,7 @@ module Redmine
         end
         content_tag('dl', out)
       end
-      
+
       desc "Displays a list of child pages. With no argument, it displays the child pages of the current wiki page. Examples:\n\n" +
              "  !{{child_pages}} -- can be used from a wiki page only\n" +
              "  !{{child_pages(Foo)}} -- lists all children of page Foo\n" +
@@ -104,7 +104,7 @@ module Redmine
         pages = ([page] + page.descendants).group_by(&:parent_id)
         render_page_hierarchy(pages, options[:parent] ? page.parent_id : page.id)
       end
-      
+
       desc "Include a wiki page. Example:\n\n  !{{include(Foo)}}\n\nor to include a page of a specific project wiki:\n\n  !{{include(projectname:Foo)}}"
       macro :include do |obj, args|
         page = Wiki.find_page(args.first.to_s, :project => @project)
