@@ -1,7 +1,17 @@
 require File.expand_path('../../test_helper', __FILE__)
 
 class AutoCompletesControllerTest < ActionController::TestCase
-  fixtures :all
+  fixtures :projects, :issues, :issue_statuses,
+           :enumerations, :users, :issue_categories,
+           :trackers,
+           :projects_trackers,
+           :roles,
+           :member_roles,
+           :members,
+           :auth_sources,
+           :enabled_modules,
+           :workflows,
+           :journals, :journal_details
 
   def test_issues_should_not_be_case_sensitive
     get :issues, :project_id => 'ecookbook', :q => 'ReCiPe'
@@ -9,14 +19,14 @@ class AutoCompletesControllerTest < ActionController::TestCase
     assert_not_nil assigns(:issues)
     assert assigns(:issues).detect {|issue| issue.subject.match /recipe/}
   end
-  
+
   def test_issues_should_return_issue_with_given_id
     get :issues, :project_id => 'subproject1', :q => '13'
     assert_response :success
     assert_not_nil assigns(:issues)
     assert assigns(:issues).include?(Issue.find(13))
   end
-  
+
   def test_auto_complete_with_scope_all_and_cross_project_relations
     Setting.cross_project_issue_relations = '1'
     get :issues, :project_id => 'ecookbook', :q => '13', :scope => 'all'
@@ -24,7 +34,7 @@ class AutoCompletesControllerTest < ActionController::TestCase
     assert_not_nil assigns(:issues)
     assert assigns(:issues).include?(Issue.find(13))
   end
-     
+
   def test_auto_complete_with_scope_all_without_cross_project_relations
     Setting.cross_project_issue_relations = '0'
     get :issues, :project_id => 'ecookbook', :q => '13', :scope => 'all'
