@@ -1,8 +1,18 @@
 require File.expand_path('../../test_helper', __FILE__)
 
 class FilesControllerTest < ActionController::TestCase
-  fixtures :all
-  
+  fixtures :projects, :trackers, :issue_statuses, :issues,
+           :enumerations, :users, :issue_categories,
+           :projects_trackers,
+           :roles,
+           :member_roles,
+           :members,
+           :enabled_modules,
+           :workflows,
+           :journals, :journal_details,
+           :attachments,
+           :versions
+
   def setup
     @controller = FilesController.new
     @request    = ActionController::TestRequest.new
@@ -16,11 +26,11 @@ class FilesControllerTest < ActionController::TestCase
     assert_response :success
     assert_template 'index'
     assert_not_nil assigns(:containers)
-    
+
     # file attached to the project
     assert_tag :a, :content => 'project_file.zip',
                    :attributes => { :href => '/attachments/download/8/project_file.zip' }
-    
+
     # file attached to a project's version
     assert_tag :a, :content => 'version_file.zip',
                    :attributes => { :href => '/attachments/download/9/version_file.zip' }
@@ -31,7 +41,7 @@ class FilesControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2
     Setting.notified_events = ['file_added']
     ActionMailer::Base.deliveries.clear
-    
+
     assert_difference 'Attachment.count' do
       post :create, :project_id => 1, :version_id => '',
            :attachments => {'1' => {'file' => uploaded_test_file('testfile.txt', 'text/plain')}}
@@ -47,12 +57,12 @@ class FilesControllerTest < ActionController::TestCase
     assert_equal "[eCookbook] New file", mail.subject
     assert mail.body.include?('testfile.txt')
   end
-  
+
   def test_create_version_file
     set_tmp_attachments_directory
     @request.session[:user_id] = 2
     Setting.notified_events = ['file_added']
-    
+
     assert_difference 'Attachment.count' do
       post :create, :project_id => 1, :version_id => '2',
            :attachments => {'1' => {'file' => uploaded_test_file('testfile.txt', 'text/plain')}}
@@ -63,5 +73,5 @@ class FilesControllerTest < ActionController::TestCase
     assert_equal 'testfile.txt', a.filename
     assert_equal Version.find(2), a.container
   end
-  
+
 end
