@@ -1,12 +1,39 @@
 require File.expand_path('../../test_helper', __FILE__)
 
 class IssueMovesControllerTest < ActionController::TestCase
-  fixtures :all
+  fixtures :projects, :trackers, :issue_statuses, :issues,
+           :enumerations, :users, :issue_categories,
+           :projects_trackers,
+           :roles,
+           :member_roles,
+           :members,
+           :enabled_modules,
+           :workflows,
+           :journals, :journal_details
 
   def setup
     User.current = nil
   end
 
+  def test_get_issue_moves_new
+    @request.session[:user_id] = 2
+    get :new, :id => 1
+
+    assert_tag :tag => 'option', :content => 'eCookbook',
+                                 :attributes => { :value => '1', :selected => 'selected' }
+    %w(new_tracker_id status_id priority_id assigned_to_id).each do |field|
+      assert_tag :tag => 'option', :content => '(No change)', :attributes => { :value => '' },
+                                   :parent => {:tag => 'select', :attributes => {:id => field}}
+      assert_no_tag :tag => 'option', :attributes => {:selected => 'selected'},
+                                      :parent => {:tag => 'select', :attributes => {:id => field}}
+    end
+
+    # Be sure we don't include inactive enumerations
+    assert ! IssuePriority.find(15).active?
+    assert_no_tag :option, :attributes => {:value => '15'},
+                           :parent => {:tag => 'select', :attributes => {:id => 'priority_id'} }
+  end
+
   def test_create_one_issue_to_another_project
     @request.session[:user_id] = 2
     post :create, :id => 1, :new_project_id => 2, :tracker_id => '', :assigned_to_id => '', :status_id => '', :start_date => '', :due_date => ''
@@ -31,7 +58,7 @@ class IssueMovesControllerTest < ActionController::TestCase
     assert_equal 1, Issue.find(1).tracker_id
     assert_equal 2, Issue.find(2).tracker_id
   end
- 
+
   def test_bulk_create_to_another_tracker
     @request.session[:user_id] = 2
     post :create, :ids => [1, 2], :new_tracker_id => 2
@@ -44,7 +71,7 @@ class IssueMovesControllerTest < ActionController::TestCase
     setup do
       @request.session[:user_id] = 2
     end
-    
+
     should "allow changing the issue priority" do
       post :create, :ids => [1, 2], :priority_id => 6
 
@@ -62,7 +89,7 @@ class IssueMovesControllerTest < ActionController::TestCase
       assert_equal 'Moving two issues', Issue.find(2).journals.sort_by(&:id).last.notes
 
     end
-    
+
   end
 
   def test_bulk_copy_to_another_project
@@ -81,7 +108,10 @@ class IssueMovesControllerTest < ActionController::TestCase
       issue_before_move = Issue.find(1)
       assert_difference 'Issue.count', 1 do
         assert_no_difference 'Project.find(1).issues.count' do
-          post :create, :ids => [1], :new_project_id => 2, :copy_options => {:copy => '1'}, :new_tracker_id => '', :assigned_to_id => '', :status_id => '', :start_date => '', :due_date => ''
+          post :create, :ids => [1], :new_project_id => 2,
+               :copy_options => {:copy => '1'}, :new_tracker_id => '',
+               :assigned_to_id => '', :status_id => '',
+               :start_date => '', :due_date => ''
         end
       end
       issue_after_move = Issue.first(:order => 'id desc', :conditions => {:project_id => 2})
@@ -89,16 +119,20 @@ class IssueMovesControllerTest < ActionController::TestCase
       assert_equal issue_before_move.status_id, issue_after_move.status_id
       assert_equal issue_before_move.assigned_to_id, issue_after_move.assigned_to_id
     end
-    
+
     should "allow changing the issue's attributes" do
       # Fixes random test failure with Mysql
-      # where Issue.all(:limit => 2, :order => 'id desc', :conditions => {:project_id => 2}) doesn't return the expected results
+      # where Issue.all(:limit => 2, :order => 'id desc', :conditions => {:project_id => 2})
+      # doesn't return the expected results
       Issue.delete_all("project_id=2")
-      
+
       @request.session[:user_id] = 2
       assert_difference 'Issue.count', 2 do
         assert_no_difference 'Project.find(1).issues.count' do
-          post :create, :ids => [1, 2], :new_project_id => 2, :copy_options => {:copy => '1'}, :new_tracker_id => '', :assigned_to_id => 4, :status_id => 3, :start_date => '2009-12-01', :due_date => '2009-12-31'
+          post :create, :ids => [1, 2], :new_project_id => 2,
+               :copy_options => {:copy => '1'}, :new_tracker_id => '',
+               :assigned_to_id => 4, :status_id => 3,
+               :start_date => '2009-12-01', :due_date => '2009-12-31'
         end
       end
 
@@ -116,9 +150,12 @@ class IssueMovesControllerTest < ActionController::TestCase
     should "allow adding a note when copying" do
       @request.session[:user_id] = 2
       assert_difference 'Issue.count', 1 do
-        post :create, :ids => [1], :copy_options => {:copy => '1'}, :notes => 'Copying one issue', :new_tracker_id => '', :assigned_to_id => 4, :status_id => 3, :start_date => '2009-12-01', :due_date => '2009-12-31'
+        post :create, :ids => [1], :copy_options => {:copy => '1'},
+             :notes => 'Copying one issue', :new_tracker_id => '',
+             :assigned_to_id => 4, :status_id => 3,
+             :start_date => '2009-12-01', :due_date => '2009-12-31'
       end
-      
+
       issue = Issue.first(:order => 'id DESC')
       assert_equal 1, issue.journals.size
       journal = issue.journals.first
@@ -126,7 +163,7 @@ class IssueMovesControllerTest < ActionController::TestCase
       assert_equal 'Copying one issue', journal.notes
     end
   end
-  
+
   def test_copy_to_another_project_should_follow_when_needed
     @request.session[:user_id] = 2
     post :create, :ids => [1], :new_project_id => 2, :copy_options => {:copy => '1'}, :follow => '1'
