@@ -22,10 +22,10 @@ require 'repositories_controller'
 class RepositoriesController; def rescue_action(e) raise e end; end
 
 class RepositoriesFilesystemControllerTest < ActionController::TestCase
-  fixtures :projects, :users, :roles, :members, :member_roles, :repositories, :enabled_modules
+  fixtures :projects, :users, :roles, :members, :member_roles,
+           :repositories, :enabled_modules
 
-  # No '..' in the repository path
-  REPOSITORY_PATH = RAILS_ROOT.gsub(%r{config\/\.\.}, '') + '/tmp/test/filesystem_repository'
+  REPOSITORY_PATH = Rails.root.join('tmp/test/filesystem_repository').to_s
   PRJ_ID = 3
 
   def setup
@@ -36,8 +36,9 @@ class RepositoriesFilesystemControllerTest < ActionController::TestCase
     @response   = ActionController::TestResponse.new
     User.current = nil
     Setting.enabled_scm << 'Filesystem' unless Setting.enabled_scm.include?('Filesystem')
+    @project = Project.find(PRJ_ID)
     @repository = Repository::Filesystem.create(
-                      :project       => Project.find(PRJ_ID),
+                      :project       => @project,
                       :url           => REPOSITORY_PATH,
                       :path_encoding => ''
                       )
@@ -115,6 +116,36 @@ class RepositoriesFilesystemControllerTest < ActionController::TestCase
         assert_equal 'text/plain', @response.content_type
       end
     end
+
+    def test_destroy_valid_repository
+      @request.session[:user_id] = 1 # admin
+
+      get :destroy, :id => PRJ_ID
+      assert_response 302
+      @project.reload
+      assert_nil @project.repository
+    end
+
+    def test_destroy_invalid_repository
+      @request.session[:user_id] = 1 # admin
+
+      get :destroy, :id => PRJ_ID
+      assert_response 302
+      @project.reload
+      assert_nil @project.repository
+
+      @repository = Repository::Filesystem.create(
+                      :project       => Project.find(PRJ_ID),
+                      :url           => "/invalid",
+                      :path_encoding => ''
+                      )
+      assert @repository
+
+      get :destroy, :id => PRJ_ID
+      assert_response 302
+      @project.reload
+      assert_nil @project.repository
+    end
   else
     puts "Filesystem test repository NOT FOUND. Skipping functional tests !!!"
     def test_fake; assert true end
