@@ -1,7 +1,14 @@
 require File.expand_path('../../../test_helper', __FILE__)
 
 class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
-  fixtures :all
+  fixtures :projects, :trackers, :issue_statuses, :issues,
+           :enumerations, :users, :issue_categories,
+           :projects_trackers,
+           :roles,
+           :member_roles,
+           :members,
+           :enabled_modules,
+           :workflows
 
   def setup
     Setting.rest_api_enabled = '0'
@@ -12,7 +19,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
     Setting.rest_api_enabled = '1'
     Setting.login_required = '0'
   end
-  
+
   # Using the NewsController because it's a simple API.
   context "get /news with the API disabled" do
 
@@ -23,7 +30,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
           @token = Token.generate!(:user => @user, :action => 'api')
           get "/news.xml?key=#{@token.value}"
         end
-        
+
         should_respond_with :unauthorized
         should_respond_with_content_type :xml
         should "not login as the user" do
@@ -37,7 +44,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
           @authorization = ActionController::HttpAuthentication::Basic.encode_credentials(@user.login, 'my_password')
           get "/news.xml", nil, :authorization => @authorization
         end
-        
+
         should_respond_with :unauthorized
         should_respond_with_content_type :xml
         should "not login as the user" do
@@ -52,7 +59,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
           @authorization = ActionController::HttpAuthentication::Basic.encode_credentials(@token.value, 'X')
           get "/news.xml", nil, :authorization => @authorization
         end
-        
+
         should_respond_with :unauthorized
         should_respond_with_content_type :xml
         should "not login as the user" do
@@ -68,7 +75,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
           @token = Token.generate!(:user => @user, :action => 'api')
           get "/news.json?key=#{@token.value}"
         end
-        
+
         should_respond_with :unauthorized
         should_respond_with_content_type :json
         should "not login as the user" do
@@ -82,7 +89,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
           @authorization = ActionController::HttpAuthentication::Basic.encode_credentials(@user.login, 'my_password')
           get "/news.json", nil, :authorization => @authorization
         end
-        
+
         should_respond_with :unauthorized
         should_respond_with_content_type :json
         should "not login as the user" do
@@ -104,7 +111,7 @@ class ApiTest::DisabledRestApiTest < ActionController::IntegrationTest
           assert_equal User.anonymous, User.current
         end
       end
-      
-    end    
+
+    end
   end
 end
