@@ -1,16 +1,16 @@
 # Redmine - project management software
-# Copyright (C) 2006-2010  Jean-Philippe Lang
+# Copyright (C) 2006-2011  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -18,12 +18,20 @@
 require File.expand_path('../../../test_helper', __FILE__)
 
 class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
-  fixtures :all
-  
+  fixtures :projects, :trackers, :issue_statuses, :issues,
+           :enumerations, :users, :issue_categories,
+           :projects_trackers,
+           :roles,
+           :member_roles,
+           :members,
+           :enabled_modules,
+           :workflows,
+           :time_entries
+
   def setup
     Setting.rest_api_enabled = '1'
   end
-  
+
   context "GET /time_entries.xml" do
     should "return time entries" do
       get '/time_entries.xml', {}, :authorization => credentials('jsmith')
@@ -32,8 +40,18 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
       assert_tag :tag => 'time_entries',
         :child => {:tag => 'time_entry', :child => {:tag => 'id', :content => '2'}}
     end
+
+    context "with limit" do
+      should "return limited results" do
+        get '/time_entries.xml?limit=2', {}, :authorization => credentials('jsmith')
+        assert_response :success
+        assert_equal 'application/xml', @response.content_type
+        assert_tag :tag => 'time_entries',
+          :children => {:count => 2}
+      end
+    end
   end
-  
+
   context "GET /time_entries/2.xml" do
     should "return requested time entry" do
       get '/time_entries/2.xml', {}, :authorization => credentials('jsmith')
@@ -43,7 +61,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
         :child => {:tag => 'id', :content => '2'}
     end
   end
-  
+
   context "POST /time_entries.xml" do
     context "with issue_id" do
       should "return create time entry" do
@@ -52,7 +70,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
         end
         assert_response :created
         assert_equal 'application/xml', @response.content_type
-        
+
         entry = TimeEntry.first(:order => 'id DESC')
         assert_equal 'jsmith', entry.user.login
         assert_equal Issue.find(1), entry.issue
@@ -62,7 +80,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
         assert_equal TimeEntryActivity.find(11), entry.activity
       end
     end
-    
+
     context "with project_id" do
       should "return create time entry" do
         assert_difference 'TimeEntry.count' do
@@ -70,7 +88,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
         end
         assert_response :created
         assert_equal 'application/xml', @response.content_type
-        
+
         entry = TimeEntry.first(:order => 'id DESC')
         assert_equal 'jsmith', entry.user.login
         assert_nil entry.issue
@@ -80,7 +98,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
         assert_equal TimeEntryActivity.find(11), entry.activity
       end
     end
-    
+
     context "with invalid parameters" do
       should "return errors" do
         assert_no_difference 'TimeEntry.count' do
@@ -93,7 +111,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
       end
     end
   end
-  
+
   context "PUT /time_entries/2.xml" do
     context "with valid parameters" do
       should "update time entry" do
@@ -117,7 +135,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
       end
     end
   end
-  
+
   context "DELETE /time_entries/2.xml" do
     should "destroy time entry" do
       assert_difference 'TimeEntry.count', -1 do
@@ -127,7 +145,7 @@ class ApiTest::TimeEntriesTest < ActionController::IntegrationTest
       assert_nil TimeEntry.find_by_id(2)
     end
   end
-  
+
   def credentials(user, password=nil)
     ActionController::HttpAuthentication::Basic.encode_credentials(user, password || user)
   end
