@@ -1,16 +1,16 @@
 # Redmine - project management software
-# Copyright (C) 2006-2009  Jean-Philippe Lang
+# Copyright (C) 2006-2011  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -19,12 +19,19 @@ require File.expand_path('../../../../test_helper', __FILE__)
 
 class MenuManagerTest < ActionController::IntegrationTest
   include Redmine::I18n
-  
-  fixtures :all
-  
+
+  fixtures :projects, :trackers, :issue_statuses, :issues,
+           :enumerations, :users, :issue_categories,
+           :projects_trackers,
+           :roles,
+           :member_roles,
+           :members,
+           :enabled_modules,
+           :workflows
+
   def test_project_menu_with_specific_locale
     get 'projects/ecookbook/issues', { }, 'Accept-Language' => 'fr,fr-fr;q=0.8,en-us;q=0.5,en;q=0.3'
-    
+
     assert_tag :div, :attributes => { :id => 'main-menu' },
                      :descendant => { :tag => 'li', :child => { :tag => 'a', :content => ll('fr', :label_activity),
                                                                              :attributes => { :href => '/projects/ecookbook/activity',
@@ -34,7 +41,7 @@ class MenuManagerTest < ActionController::IntegrationTest
                                                                              :attributes => { :href => '/projects/ecookbook/issues',
                                                                                               :class => 'issues selected' } } }
   end
-  
+
   def test_project_menu_with_additional_menu_items
     Setting.default_language = 'en'
     assert_no_difference 'Redmine::MenuManager.items(:project_menu).size' do
@@ -43,12 +50,12 @@ class MenuManagerTest < ActionController::IntegrationTest
         menu.push :bar, { :controller => 'projects', :action => 'show' }, :before => :activity
         menu.push :hello, { :controller => 'projects', :action => 'show' }, :caption => Proc.new {|p| p.name.upcase }, :after => :bar
       end
-      
+
       get 'projects/ecookbook'
       assert_tag :div, :attributes => { :id => 'main-menu' },
                        :descendant => { :tag => 'li', :child => { :tag => 'a', :content => 'Foo',
                                                                                :attributes => { :class => 'foo' } } }
-  
+
       assert_tag :div, :attributes => { :id => 'main-menu' },
                        :descendant => { :tag => 'li', :child => { :tag => 'a', :content => 'Bar',
                                                                                :attributes => { :class => 'bar' } },
@@ -58,7 +65,7 @@ class MenuManagerTest < ActionController::IntegrationTest
                        :descendant => { :tag => 'li', :child => { :tag => 'a', :content => 'ECOOKBOOK',
                                                                                :attributes => { :class => 'hello' } },
                                                       :before => { :tag => 'li', :child => { :tag => 'a', :content => 'Activity' } } }
-      
+
       # Remove the menu items
       Redmine::MenuManager.map :project_menu do |menu|
         menu.delete :foo
