@@ -1,16 +1,16 @@
-# redMine - project management software
-# Copyright (C) 2006-2008  Jean-Philippe Lang
+# Redmine - project management software
+# Copyright (C) 2006-2011  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -19,37 +19,60 @@ require File.expand_path('../../test_helper', __FILE__)
 
 class RepositoryDarcsTest < ActiveSupport::TestCase
   fixtures :projects
-  
-  # No '..' in the repository path
-  REPOSITORY_PATH = RAILS_ROOT.gsub(%r{config\/\.\.}, '') + '/tmp/test/darcs_repository'
-  
+
+  REPOSITORY_PATH = Rails.root.join('tmp/test/darcs_repository').to_s
+  NUM_REV = 6
+
   def setup
-    @project = Project.find(1)
-    assert @repository = Repository::Darcs.create(:project => @project, :url => REPOSITORY_PATH)
+    @project = Project.find(3)
+    @repository = Repository::Darcs.create(
+                      :project      => @project,
+                      :url          => REPOSITORY_PATH,
+                      :log_encoding => 'UTF-8'
+                      )
+    assert @repository
   end
-  
-  if File.directory?(REPOSITORY_PATH)  
+
+  if File.directory?(REPOSITORY_PATH)
     def test_fetch_changesets_from_scratch
+      assert_equal 0, @repository.changesets.count
       @repository.fetch_changesets
-      @repository.reload
-      
-      assert_equal 6, @repository.changesets.count
+      @project.reload
+
+      assert_equal NUM_REV, @repository.changesets.count
       assert_equal 13, @repository.changes.count
       assert_equal "Initial commit.", @repository.changesets.find_by_revision('1').comments
     end
-    
+
     def test_fetch_changesets_incremental
+      assert_equal 0, @repository.changesets.count
       @repository.fetch_changesets
+      @project.reload
+      assert_equal NUM_REV, @repository.changesets.count
+
       # Remove changesets with revision > 3
       @repository.changesets.find(:all).each {|c| c.destroy if c.revision.to_i > 3}
-      @repository.reload
+      @project.reload
       assert_equal 3, @repository.changesets.count
-      
+
       @repository.fetch_changesets
-      assert_equal 6, @repository.changesets.count
+      @project.reload
+      assert_equal NUM_REV, @repository.changesets.count
     end
-    
+
+    def test_entries_invalid_revision
+      assert_equal 0, @repository.changesets.count
+      @repository.fetch_changesets
+      @project.reload
+      assert_equal NUM_REV, @repository.changesets.count
+      assert_nil @repository.entries('', '123')
+    end
+
     def test_deleted_files_should_not_be_listed
+      assert_equal 0, @repository.changesets.count
+      @repository.fetch_changesets
+      @project.reload
+      assert_equal NUM_REV, @repository.changesets.count
       entries = @repository.entries('sources')
       assert entries.detect {|e| e.name == 'watchers_controller.rb'}
       assert_nil entries.detect {|e| e.name == 'welcome_controller.rb'}
@@ -57,7 +80,10 @@ class RepositoryDarcsTest < ActiveSupport::TestCase
 
     def test_cat
       if @repository.scm.supports_cat?
+        assert_equal 0, @repository.changesets.count
         @repository.fetch_changesets
+        @project.reload
+        assert_equal NUM_REV, @repository.changesets.count
         cat = @repository.cat("sources/welcome_controller.rb", 2)
         assert_not_nil cat
         assert cat.include?('class WelcomeController < ApplicationController')
